summaryrefslogtreecommitdiffstats
path: root/quanta/project/project.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/project/project.h')
-rw-r--r--quanta/project/project.h82
1 files changed, 41 insertions, 41 deletions
diff --git a/quanta/project/project.h b/quanta/project/project.h
index b6775da7..95995036 100644
--- a/quanta/project/project.h
+++ b/quanta/project/project.h
@@ -18,7 +18,7 @@
#ifndef PROJECT_H
#define PROJECT_H
-#include <qobject.h>
+#include <tqobject.h>
#include "projecturl.h"
@@ -30,7 +30,7 @@ namespace KTextEditor{
class ViewCursorInterface;
}
struct EventAction;
-typedef QMap<QString, QValueList<EventAction> > EventActions;
+typedef TQMap<TQString, TQValueList<EventAction> > EventActions;
/**project
*@author Yacovlev Alexander & Dmitry Poplavsky & Andras Mantia & Jens Herden
@@ -40,18 +40,18 @@ class KConfig;
class KMainWindow;
struct TeamMember {
- QString name;
- QString email;
- QString nickName;
- QString task;
+ TQString name;
+ TQString email;
+ TQString nickName;
+ TQString task;
};
struct SubProject {
- QString name;
- QString location;
+ TQString name;
+ TQString location;
};
-class Project : public QObject {
+class Project : public TQObject {
Q_OBJECT
friend class ProjectPrivate; // need this because I use the signals
@@ -73,9 +73,9 @@ public:
~Project();
bool hasProject();
- QString projectName();
+ TQString projectName();
- QStringList fileNameList();
+ TQStringList fileNameList();
KURL::List files();
void insertFile( const KURL& nameURL, bool repaint );
@@ -87,9 +87,9 @@ public:
/** Returns the relative url with the prefix inserted. */
KURL urlWithPrefix(const KURL& url);
bool contains(const KURL &url);
- /** Read property of QString defaultDTD. */
- const QString& defaultDTD();
- const QString& defaultEncoding();
+ /** Read property of TQString defaultDTD. */
+ const TQString& defaultDTD();
+ const TQString& defaultEncoding();
/** Returns the project's base URL if it exists,
* the HOME dir if there is no project and no opened document
@@ -100,17 +100,17 @@ public:
KURL documentFolderForURL(const KURL &url);
/** Saves the password for entry into a list. Stores on disc if store == true */
- void savePassword(const QString& entry, const QString& passwd, bool store);
+ void savePassword(const TQString& entry, const TQString& passwd, bool store);
/** Returns the saved password for entry */
- QString password(const QString &entry);
- bool passwordSaved(const QString &entry);
- QDomDocument *dom();
- QDomDocument *sessionDom();
- QString debuggerClient();
+ TQString password(const TQString &entry);
+ bool passwordSaved(const TQString &entry);
+ TQDomDocument *dom();
+ TQDomDocument *sessionDom();
+ TQString debuggerClient();
bool debuggerPersistentBreakpoints();
bool debuggerPersistentWatches();
bool keepPasswd;
- QString email();
+ TQString email();
KURL templateURL();
KURL toolbarURL();
EventActions* events();
@@ -118,21 +118,21 @@ public:
* Get the nickname of the current user (you)
* @return the nickname
*/
- QString yourself();
+ TQString yourself();
/**
* Get the roles of the current user in the form "role:task".
* Examples: "team leader", "project leader:subprojectname", "task leader:taskname".
* @return the roles (in lowercase)
*/
- QStringList yourRoles();
+ TQStringList yourRoles();
TeamMember teamLeader();
- TeamMember subprojectLeader(const QString &name);
- TeamMember taskLeader(const QString &name);
- QValueList<TeamMember> simpleMembers();
- QString mailingList();
- QValueList<SubProject>* subprojects();
- QStringList tasks();
- QMap<QString, TeamMember> allMembers();
+ TeamMember subprojectLeader(const TQString &name);
+ TeamMember taskLeader(const TQString &name);
+ TQValueList<TeamMember> simpleMembers();
+ TQString mailingList();
+ TQValueList<SubProject>* subprojects();
+ TQStringList tasks();
+ TQMap<TQString, TeamMember> allMembers();
bool eventsEnabled();
void setProjectToolbarVisible(bool visible) {m_projectToolbarVisible = visible;}
@@ -157,7 +157,7 @@ public slots:
void slotOpenProject(const KURL&);
void slotOptions();
void slotUpload();
- void slotUploadURL(const KURL &urlToUpload, const QString &profileName, bool quickUpload, bool markOnly);
+ void slotUploadURL(const KURL &urlToUpload, const TQString &profileName, bool quickUpload, bool markOnly);
void slotAddDirectory(const KURL& dirURL, bool showDlg = true);
void slotInsertFile(const KURL& url);
@@ -168,10 +168,10 @@ public slots:
void slotRemove(const KURL& urlToRemove);
- void slotGetMessages(const QString&);
+ void slotGetMessages(const TQString&);
void slotRescanPrjDir();
- void slotFileDescChanged(const KURL& url, const QString& desc);
+ void slotFileDescChanged(const KURL& url, const TQString& desc);
void slotUploadStatusChanged(const KURL& url, int status);
void slotChangeDocumentFolderStatus(const KURL& url, bool status);
@@ -183,28 +183,28 @@ public slots:
signals:
- void openFile( const KURL&, const QString& );
- void openFiles( const KURL::List&, const QString& );
+ void openFile( const KURL&, const TQString& );
+ void openFiles( const KURL::List&, const TQString& );
void closeFile( const KURL&);
void closeFiles();
- void reloadTree(ProjectList *, bool, const QStringList &);
+ void reloadTree(ProjectList *, bool, const TQStringList &);
- void messages(const QString& );
+ void messages(const TQString& );
void enableMessageWidget();
void newStatus();
- void statusMsg(const QString &);
+ void statusMsg(const TQString &);
/** No descriptions */
- void newProjectLoaded(const QString &, const KURL &, const KURL &);
+ void newProjectLoaded(const TQString &, const KURL &, const KURL &);
void reloadProjectDocs();
void hideSplash();
void addProjectDoc(const KURL &);
void getUserToolbarFiles(KURL::List *);
void loadToolbarFile(const KURL &);
/** ask for the tree status for saving in project */
- void getTreeStatus(QStringList *);
- void eventHappened(const QString&, const QString&, const QString& );
+ void getTreeStatus(TQStringList *);
+ void eventHappened(const TQString&, const TQString&, const TQString& );
private:
/** The constructor is privat because we use singleton patter.